Welcome to |project| documentation!
===================================

.. sidebar-links::
   :home:
   :pypi:

.. toctree::
   :maxdepth: 1

   history


.. automodule:: jaraco.mongodb
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.codec
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.fields
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.fixtures
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.helper
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.migration
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.oplog
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.query
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.sessions
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.sharding
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.timers
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: jaraco.mongodb.uri
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

